@@ -47,10 +47,4 @@ class SearchAlertContactGroupRequest(RpcRequest):
 		return self.get_query_params().get('ContactGroupName')
 
 	def set_ContactGroupName(self,ContactGroupName):
-		self.add_query_param('ContactGroupName',ContactGroupName)
-
-	def get_ProxyUserId(self):
-		return self.get_query_params().get('ProxyUserId')
-
-	def set_ProxyUserId(self,ProxyUserId):
-		self.add_query_param('ProxyUserId',ProxyUserId)
\ No newline at end of file
+		self.add_query_param('ContactGroupName',ContactGroupName)
\ No newline at end of file
